# index-generator

Yet another python index generator

[![Travis](https://img.shields.io/travis/BruceZhang1993/index-generator.svg?style=for-the-badge)](https://travis-ci.org/BruceZhang1993/index-generator)
[![PyPI](https://img.shields.io/pypi/v/index-generator.svg?style=for-the-badge)](https://pypi.org/project/index-generator)

## Install

### GitHub master branch

```bash
git clone https://github.com/BruceZhang1993/index-generator.git
cd index-generator
sudo python setup.py install
# OR
sudo pip install .
```

### GitHub release

```bash
# Coming soon
```

### Pypi

```bash
# Coming soon
```

### Distributions

#### Arch Linux

```bash
# Coming soon
```

#### Other Distribution

## Usage

See [Wiki Page](https://github.com/BruceZhang1993/index-generator/wiki)

## License

[MIT](https://github.com/BruceZhang1993/index-generator/blob/master/LICENSE)

## Contributors
    Sorting by alphabet order. 
- Bruce Zhang ([BruceZhang1993](https://github.com/BruceZhang1993))
- Edward P ([edward-p](https://github.com/edward-p))

[More...](https://github.com/BruceZhang1993/index-generator/graphs/contributors)
